@@ -7,6 +7,12 @@ import dolly
 import terminal
 import sys
 import os
+import pkg_resources
+
+def printVersion():
+	version = pkg_resources.require("Dolly")[0].version
+	sys.exit(0)
+
 
 def isGitRepo(repo):
 	return repo['remote'].endswith('.git')
@@ -55,6 +61,4 @@ def checkRemote(repo):
 	else:
 		command = 'svn info '
 	result = executeCommand(command, cwd=repo['local'])
-	print repo
-	print result
 	return (repo['remote'] in result['stdout']) or (result['returncode'] != 0)
